==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RangeColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalRangeCategorySeriesDescriptionMetadata } from "./HorizontalRangeCategorySeriesDescriptionMetadata";
import { RangeColumnSeriesDescription } from "./RangeColumnSeriesDescription";
/**
 * @hidden
 */
var RangeColumnSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeColumnSeriesDescriptionMetadata, _super);
    function RangeColumnSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RangeColumnSeriesDescriptionMetadata.b = function (a) {
        if (RangeColumnSeriesDescriptionMetadata.a == null) {
            RangeColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RangeColumnSeriesDescriptionMetadata.c(RangeColumnSeriesDescriptionMetadata.a);
        }
        if (a.g(RangeColumnSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(RangeColumnSeriesDescriptionMetadata.a);
    };
    RangeColumnSeriesDescriptionMetadata.c = function (a) {
        HorizontalRangeCategorySeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    RangeColumnSeriesDescriptionMetadata.d = function (a) {
        RangeColumnSeriesDescriptionMetadata.b(a);
        a.u("RangeColumnSeries", function () { return new RangeColumnSeriesDescription(); });
        a.t("RangeColumnSeries", RangeColumnSeriesDescriptionMetadata.a);
    };
    RangeColumnSeriesDescriptionMetadata.$t = markType(RangeColumnSeriesDescriptionMetadata, 'RangeColumnSeriesDescriptionMetadata');
    RangeColumnSeriesDescriptionMetadata.a = null;
    return RangeColumnSeriesDescriptionMetadata;
}(Base));
export { RangeColumnSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RangeColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalRangeCategorySeriesDescriptionMetadata } from "./HorizontalRangeCategorySeriesDescriptionMetadata";
import { RangeColumnSeriesDescription } from "./RangeColumnSeriesDescription";
/**
 * @hidden
 */
var RangeColumnSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeColumnSeriesDescriptionMetadata, _super);
    function RangeColumnSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RangeColumnSeriesDescriptionMetadata.b = function (a) {
        if (RangeColumnSeriesDescriptionMetadata.a == null) {
            RangeColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RangeColumnSeriesDescriptionMetadata.c(RangeColumnSeriesDescriptionMetadata.a);
        }
        if (a.j(RangeColumnSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(RangeColumnSeriesDescriptionMetadata.a);
    };
    RangeColumnSeriesDescriptionMetadata.c = function (a) {
        HorizontalRangeCategorySeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    RangeColumnSeriesDescriptionMetadata.d = function (a) {
        RangeColumnSeriesDescriptionMetadata.b(a);
        a.aa("RangeColumnSeries", function () { return new RangeColumnSeriesDescription(); });
        a.z("RangeColumnSeries", RangeColumnSeriesDescriptionMetadata.a);
    };
    RangeColumnSeriesDescriptionMetadata.$t = markType(RangeColumnSeriesDescriptionMetadata, 'RangeColumnSeriesDescriptionMetadata');
    RangeColumnSeriesDescriptionMetadata.a = null;
    return RangeColumnSeriesDescriptionMetadata;
}(Base));
export { RangeColumnSeriesDescriptionMetadata };
